==> ViennaCL-1.7.0.tar.gz: ViennaCL-1.7.0/doc/html/search/classes_2.js <==
var searchData=
[
  ['cg_5fsolver',['cg_solver',['../classviennacl_1_1linalg_1_1cg__solver.html',1,'viennacl::linalg']]],
  ['cg_5ftag',['cg_tag',['../classviennacl_1_1linalg_1_1cg__tag.html',1,'viennacl::linalg']]],
  ['char_5fto_5ftype',['char_to_type',['../structviennacl_1_1device__specific_1_1char__to__type.html',1,'viennacl::device_specific']]],
  ['check_5fscalar_5ftemplate_5fargument',['CHECK_SCALAR_TEMPLATE_ARGUMENT',['../structviennacl_1_1tools_1_1_c_h_e_c_k___s_c_a_l_a_r___t_e_m_p_l_a_t_e___a_r_g_u_m_e_n_t.html',1,'viennacl::tools']]],
  ['chow_5fpatel_5ficc_5fprecond',['chow_patel_icc_precond',['../classviennacl_1_1linalg_1_1chow__patel__icc__precond.html',1,'viennacl::linalg']]],
  ['chow_5fpatel_5ficc_5fprecond_3c_20viennacl_3a_3acompressed_5fmatrix_3c_20numerict_2c_20alignmentv_20_3e_20_3e',['chow_patel_icc_precond&lt; viennacl::compressed_matrix&lt; NumericT, AlignmentV &gt; &gt;',['../classviennacl_1_1linalg_1_1chow__patel__icc__precond_3_01viennacl_1_1compressed__matrix_3_01_num12c156ca568277646db4ffa0c9da3134.html',1,'viennacl::linalg']]],
  ['chow_5fpatel_5filu_5fprecond',['chow_patel_ilu_precond',['../classviennacl_1_1linalg_1_1chow__patel__ilu__precond.html',1,'viennacl::linalg']]],
  ['chow_5fpatel_5filu_5fprecond_3c_20viennacl_3a_3acompressed_5fmatrix_3c_20numerict_2c_20alignmentv_20_3e_20_3e',['chow_patel_ilu_precond&lt; viennacl::compressed_matrix&lt; NumericT, AlignmentV &gt; &gt;',['../classviennacl_1_1linalg_1_1chow__patel__ilu__precond_3_01viennacl_1_1compressed__matrix_3_01_num1d4c01a16bf6e4ce8c15fcd9140c68ca.html',1,'viennacl::linalg']]],
  ['chow_5fpatel_5ftag',['chow_patel_tag',['../classviennacl_1_1linalg_1_1chow__patel__tag.html',1,'viennacl::linalg']]],
  ['circulant_5fmatrix',['circulant_matrix',['../classviennacl_1_1circulant__matrix.html',1,'viennacl']]],
  ['cl_5ftype',['cl_type',['../structviennacl_1_1result__of_1_1cl__type.html',1,'viennacl::result_of']]],
  ['col_5fiteration',['col_iteration',['../structviennacl_1_1col__iteration.html',1,'viennacl']]],
  ['column_5fmajor',['column_major',['../structviennacl_1_1column__major.html',1,'viennacl']]],
  ['column_5fmajor_5ftag',['column_major_tag',['../structviennacl_1_1column__major__tag.html',1,'viennacl']]],
  ['command_5fqueue',['command_queue',['../classviennacl_1_1ocl_1_1command__queue.html',1,'viennacl::ocl']]],
  ['comparesecond',['CompareSecond',['../structviennacl_1_1linalg_1_1detail_1_1spai_1_1_compare_second.html',1,'viennacl::linalg::detail::spai']]],
  ['compiler_5fnot_5favailable',['compiler_not_available',['../classviennacl_1_1ocl_1_1compiler__not__available.html',1,'viennacl::ocl']]],
  ['compressed_5fcompressed_5fmatrix',['compressed_compressed_matrix',['../classviennacl_1_1compressed__compressed__matrix.html',1,'viennacl']]],
  ['compressed_5fcompressed_5fmatrix',['compressed_compressed_matrix',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1compressed__compressed__matrix.html',1,'viennacl::linalg::opencl::kernels']]],
  ['compressed_5fmatrix',['compressed_matrix',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1compressed__matrix.html',1,'viennacl::linalg::opencl::kernels']]],
  ['compressed_5fmatrix',['compressed_matrix',['../classviennacl_1_1compressed__matrix.html',1,'viennacl']]],
  ['compressed_5fmatrix_3c_20double_20_3e',['compressed_matrix&lt; double &gt;',['../classviennacl_1_1compressed__matrix.html',1,'viennacl']]],
  ['compressed_5fmatrix_3c_20float_20_3e',['compressed_matrix&lt; float &gt;',['../classviennacl_1_1compressed__matrix.html',1,'viennacl']]],
  ['compressed_5fmatrix_3c_20numerict_20_3e',['compressed_matrix&lt; NumericT &gt;',['../classviennacl_1_1compressed__matrix.html',1,'viennacl']]],
  ['compressed_5fmatrix_3c_20numerictype_20_3e',['compressed_matrix&lt; NumericType &gt;',['../classviennacl_1_1compressed__matrix.html',1,'viennacl']]],
  ['compressed_5fmatrix_3c_20scalartype_2c_20mat_5falignment_20_3e',['compressed_matrix&lt; ScalarType, MAT_ALIGNMENT &gt;',['../classviennacl_1_1compressed__matrix.html',1,'viennacl']]],
  ['const_5fentry_5fproxy',['const_entry_proxy',['../classviennacl_1_1const__entry__proxy.html',1,'viennacl']]],
  ['const_5fremover',['CONST_REMOVER',['../structviennacl_1_1tools_1_1_c_o_n_s_t___r_e_m_o_v_e_r.html',1,'viennacl::tools']]],
  ['const_5fsparse_5fmatrix_5fadapted_5fiterator',['const_sparse_matrix_adapted_iterator',['../classviennacl_1_1tools_1_1const__sparse__matrix__adapted__iterator.html',1,'viennacl::tools']]],
  ['const_5fsparse_5fmatrix_5fadapter',['const_sparse_matrix_adapter',['../classviennacl_1_1tools_1_1const__sparse__matrix__adapter.html',1,'viennacl::tools']]],
  ['const_5fvector_5fiterator',['const_vector_iterator',['../classviennacl_1_1const__vector__iterator.html',1,'viennacl']]],
  ['context',['context',['../classviennacl_1_1context.html',1,'viennacl']]],
  ['context',['context',['../classviennacl_1_1ocl_1_1context.html',1,'viennacl::ocl']]],
  ['convert_5fto_5fopencl',['convert_to_opencl',['../structviennacl_1_1backend_1_1detail_1_1convert__to__opencl.html',1,'viennacl::backend::detail']]],
  ['coordinate_5fmatrix',['coordinate_matrix',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1coordinate__matrix.html',1,'viennacl::linalg::opencl::kernels']]],
  ['coordinate_5fmatrix',['coordinate_matrix',['../classviennacl_1_1coordinate__matrix.html',1,'viennacl']]],
  ['coordinate_5fmatrix_3c_20double_20_3e',['coordinate_matrix&lt; double &gt;',['../classviennacl_1_1coordinate__matrix.html',1,'viennacl']]],
  ['coordinate_5fmatrix_3c_20float_20_3e',['coordinate_matrix&lt; float &gt;',['../classviennacl_1_1coordinate__matrix.html',1,'viennacl']]],
  ['count',['count',['../classviennacl_1_1tools_1_1detail_1_1count.html',1,'viennacl::tools::detail']]],
  ['cpu_5fscalar_5ftype_5fdeducer',['CPU_SCALAR_TYPE_DEDUCER',['../structviennacl_1_1tools_1_1_c_p_u___s_c_a_l_a_r___t_y_p_e___d_e_d_u_c_e_r.html',1,'viennacl::tools']]],
  ['cpu_5ftag',['cpu_tag',['../structviennacl_1_1ocl_1_1cpu__tag.html',1,'viennacl::ocl']]],
  ['cpu_5fvalue_5ftype',['cpu_value_type',['../structviennacl_1_1result__of_1_1cpu__value__type.html',1,'viennacl::result_of']]],
  ['cuda_5fdeleter',['cuda_deleter',['../structviennacl_1_1backend_1_1cuda_1_1detail_1_1cuda__deleter.html',1,'viennacl::backend::cuda::detail']]],
  ['cuda_5fexception',['cuda_exception',['../classviennacl_1_1backend_1_1cuda_1_1cuda__exception.html',1,'viennacl::backend::cuda']]],
  ['cuda_5fnot_5favailable_5fexception',['cuda_not_available_exception',['../classviennacl_1_1cuda__not__available__exception.html',1,'viennacl']]],
  ['cuthill_5fmckee_5ftag',['cuthill_mckee_tag',['../structviennacl_1_1cuthill__mckee__tag.html',1,'viennacl']]]
];

==> ViennaCL-1.7.1.tar.gz: ViennaCL-1.7.1/doc/html/search/classes_2.js <==
var searchData=
[
  ['cg_5fsolver',['cg_solver',['../classviennacl_1_1linalg_1_1cg__solver.html',1,'viennacl::linalg']]],
  ['cg_5ftag',['cg_tag',['../classviennacl_1_1linalg_1_1cg__tag.html',1,'viennacl::linalg']]],
  ['char_5fto_5ftype',['char_to_type',['../structviennacl_1_1device__specific_1_1char__to__type.html',1,'viennacl::device_specific']]],
  ['check_5fscalar_5ftemplate_5fargument',['CHECK_SCALAR_TEMPLATE_ARGUMENT',['../structviennacl_1_1tools_1_1_c_h_e_c_k___s_c_a_l_a_r___t_e_m_p_l_a_t_e___a_r_g_u_m_e_n_t.html',1,'viennacl::tools']]],
  ['chow_5fpatel_5ficc_5fprecond',['chow_patel_icc_precond',['../classviennacl_1_1linalg_1_1chow__patel__icc__precond.html',1,'viennacl::linalg']]],
  ['chow_5fpatel_5ficc_5fprecond_3c_20viennacl_3a_3acompressed_5fmatrix_3c_20numerict_2c_20alignmentv_20_3e_20_3e',['chow_patel_icc_precond&lt; viennacl::compressed_matrix&lt; NumericT, AlignmentV &gt; &gt;',['../classviennacl_1_1linalg_1_1chow__patel__icc__precond_3_01viennacl_1_1compressed__matrix_3_01_num12c156ca568277646db4ffa0c9da3134.html',1,'viennacl::linalg']]],
  ['chow_5fpatel_5filu_5fprecond',['chow_patel_ilu_precond',['../classviennacl_1_1linalg_1_1chow__patel__ilu__precond.html',1,'viennacl::linalg']]],
  ['chow_5fpatel_5filu_5fprecond_3c_20viennacl_3a_3acompressed_5fmatrix_3c_20numerict_2c_20alignmentv_20_3e_20_3e',['chow_patel_ilu_precond&lt; viennacl::compressed_matrix&lt; NumericT, AlignmentV &gt; &gt;',['../classviennacl_1_1linalg_1_1chow__patel__ilu__precond_3_01viennacl_1_1compressed__matrix_3_01_num1d4c01a16bf6e4ce8c15fcd9140c68ca.html',1,'viennacl::linalg']]],
  ['chow_5fpatel_5ftag',['chow_patel_tag',['../classviennacl_1_1linalg_1_1chow__patel__tag.html',1,'viennacl::linalg']]],
  ['circulant_5fmatrix',['circulant_matrix',['../classviennacl_1_1circulant__matrix.html',1,'viennacl']]],
  ['cl_5ftype',['cl_type',['../structviennacl_1_1result__of_1_1cl__type.html',1,'viennacl::result_of']]],
  ['col_5fiteration',['col_iteration',['../structviennacl_1_1col__iteration.html',1,'viennacl']]],
  ['column_5fmajor',['column_major',['../structviennacl_1_1column__major.html',1,'viennacl']]],
  ['column_5fmajor_5ftag',['column_major_tag',['../structviennacl_1_1column__major__tag.html',1,'viennacl']]],
  ['command_5fqueue',['command_queue',['../classviennacl_1_1ocl_1_1command__queue.html',1,'viennacl::ocl']]],
  ['comparesecond',['CompareSecond',['../structviennacl_1_1linalg_1_1detail_1_1spai_1_1_compare_second.html',1,'viennacl::linalg::detail::spai']]],
  ['compiler_5fnot_5favailable',['compiler_not_available',['../classviennacl_1_1ocl_1_1compiler__not__available.html',1,'viennacl::ocl']]],
  ['compressed_5fcompressed_5fmatrix',['compressed_compressed_matrix',['../classviennacl_1_1compressed__compressed__matrix.html',1,'viennacl']]],
  ['compressed_5fcompressed_5fmatrix',['compressed_compressed_matrix',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1compressed__compressed__matrix.html',1,'viennacl::linalg::opencl::kernels']]],
  ['compressed_5fmatrix',['compressed_matrix',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1compressed__matrix.html',1,'viennacl::linalg::opencl::kernels']]],
  ['compressed_5fmatrix',['compressed_matrix',['../classviennacl_1_1compressed__matrix.html',1,'viennacl']]],
  ['compressed_5fmatrix_3c_20double_20_3e',['compressed_matrix&lt; double &gt;',['../classviennacl_1_1compressed__matrix.html',1,'viennacl']]],
  ['compressed_5fmatrix_3c_20float_20_3e',['compressed_matrix&lt; float &gt;',['../classviennacl_1_1compressed__matrix.html',1,'viennacl']]],
  ['compressed_5fmatrix_3c_20numerict_20_3e',['compressed_matrix&lt; NumericT &gt;',['../classviennacl_1_1compressed__matrix.html',1,'viennacl']]],
  ['compressed_5fmatrix_3c_20numerictype_20_3e',['compressed_matrix&lt; NumericType &gt;',['../classviennacl_1_1compressed__matrix.html',1,'viennacl']]],
  ['compressed_5fmatrix_3c_20scalartype_2c_20mat_5falignment_20_3e',['compressed_matrix&lt; ScalarType, MAT_ALIGNMENT &gt;',['../classviennacl_1_1compressed__matrix.html',1,'viennacl']]],
  ['compressed_5fmatrix_5fsolve',['compressed_matrix_solve',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1compressed__matrix__solve.html',1,'viennacl::linalg::opencl::kernels']]],
  ['const_5fentry_5fproxy',['const_entry_proxy',['../classviennacl_1_1const__entry__proxy.html',1,'viennacl']]],
  ['const_5fremover',['CONST_REMOVER',['../structviennacl_1_1tools_1_1_c_o_n_s_t___r_e_m_o_v_e_r.html',1,'viennacl::tools']]],
  ['const_5fsparse_5fmatrix_5fadapted_5fiterator',['const_sparse_matrix_adapted_iterator',['../classviennacl_1_1tools_1_1const__sparse__matrix__adapted__iterator.html',1,'viennacl::tools']]],
  ['const_5fsparse_5fmatrix_5fadapter',['const_sparse_matrix_adapter',['../classviennacl_1_1tools_1_1const__sparse__matrix__adapter.html',1,'viennacl::tools']]],
  ['const_5fvector_5fiterator',['const_vector_iterator',['../classviennacl_1_1const__vector__iterator.html',1,'viennacl']]],
  ['const_5fvector_5fiterator_3c_20numerict_2c_20alignmentv_20_3e',['const_vector_iterator&lt; NumericT, AlignmentV &gt;',['../classviennacl_1_1const__vector__iterator.html',1,'viennacl']]],
  ['context',['context',['../classviennacl_1_1context.html',1,'viennacl']]],
  ['context',['context',['../classviennacl_1_1ocl_1_1context.html',1,'viennacl::ocl']]],
  ['convert_5fto_5fopencl',['convert_to_opencl',['../structviennacl_1_1backend_1_1detail_1_1convert__to__opencl.html',1,'viennacl::backend::detail']]],
  ['coordinate_5fmatrix',['coordinate_matrix',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1coordinate__matrix.html',1,'viennacl::linalg::opencl::kernels']]],
  ['coordinate_5fmatrix',['coordinate_matrix',['../classviennacl_1_1coordinate__matrix.html',1,'viennacl']]],
  ['coordinate_5fmatrix_3c_20double_20_3e',['coordinate_matrix&lt; double &gt;',['../classviennacl_1_1coordinate__matrix.html',1,'viennacl']]],
  ['coordinate_5fmatrix_3c_20float_20_3e',['coordinate_matrix&lt; float &gt;',['../classviennacl_1_1coordinate__matrix.html',1,'viennacl']]],
  ['count',['count',['../classviennacl_1_1tools_1_1detail_1_1count.html',1,'viennacl::tools::detail']]],
  ['cpu_5fscalar_5ftype_5fdeducer',['CPU_SCALAR_TYPE_DEDUCER',['../structviennacl_1_1tools_1_1_c_p_u___s_c_a_l_a_r___t_y_p_e___d_e_d_u_c_e_r.html',1,'viennacl::tools']]],
  ['cpu_5ftag',['cpu_tag',['../structviennacl_1_1ocl_1_1cpu__tag.html',1,'viennacl::ocl']]],
  ['cpu_5fvalue_5ftype',['cpu_value_type',['../structviennacl_1_1result__of_1_1cpu__value__type.html',1,'viennacl::result_of']]],
  ['cuda_5fdeleter',['cuda_deleter',['../structviennacl_1_1backend_1_1cuda_1_1detail_1_1cuda__deleter.html',1,'viennacl::backend::cuda::detail']]],
  ['cuda_5fexception',['cuda_exception',['../classviennacl_1_1backend_1_1cuda_1_1cuda__exception.html',1,'viennacl::backend::cuda']]],
  ['cuda_5fnot_5favailable_5fexception',['cuda_not_available_exception',['../classviennacl_1_1cuda__not__available__exception.html',1,'viennacl']]],
  ['cuthill_5fmckee_5ftag',['cuthill_mckee_tag',['../structviennacl_1_1cuthill__mckee__tag.html',1,'viennacl']]]
];
